@@ -460,7 +460,8 @@ void D_PageTicker(void)
 
 void D_PageDrawer(void)
 {
-  V_DrawPatchFullScreen(V_CachePatchName(pagename, PU_CACHE));
+  V_DrawPatchFullScreen(
+    V_CachePatchName(W_CheckWidescreenPatch(pagename), PU_CACHE));
 }
 
 //
@@ -487,20 +488,12 @@ void D_DoAdvanceDemo(void)
     usergame = false; // no save / end game here
     paused = false;
     gameaction = ga_nothing;
+    gamestate = GS_DEMOSCREEN;
 
     D_AdvanceDemoLoop();
     switch (demoloop_point->type)
     {
         case TYPE_ART:
-            gamestate = GS_DEMOSCREEN;
-
-            // Needed to support the Doom 3: BFG Edition variant
-            if (W_CheckNumForName(demoloop_point->primary_lump) < 0
-                && !strcasecmp(demoloop_point->primary_lump, "TITLEPIC"))
-            {
-                M_CopyLumpName(demoloop_point->primary_lump, "DMENUPIC");
-            }
-
             if (W_CheckNumForName(demoloop_point->primary_lump) >= 0)
             {
                 pagename = demoloop_point->primary_lump;
@@ -510,24 +503,18 @@ void D_DoAdvanceDemo(void)
                 {
                     S_ChangeMusInfoMusic(music, false);
                 }
-                break;
             }
-            // fallthrough
+            break;
 
         case TYPE_DEMO:
-            gamestate = GS_DEMOSCREEN;
-
             if (W_CheckNumForName(demoloop_point->primary_lump) >= 0)
             {
                 G_DeferedPlayDemo(demoloop_point->primary_lump);
-                break;
             }
-            // fallthrough
+            break;
 
         default:
-            I_Printf(VB_WARNING,
-                     "D_DoAdvanceDemo: Invalid demoloop[%d] entry, skipping",
-                     demosequence);
+            I_Printf(VB_DEBUG, "D_DoAdvanceDemo: unhandled demoloop type");
             break;
     }
 }
@@ -1351,6 +1338,10 @@ static void LoadIWadBase(void)
     {
         W_AddBaseDir("doom-all");
     }
+    else if (local_gamemission == pack_chex || local_gamemission == pack_chex3v)
+    {
+        W_AddBaseDir("chex-all");
+    }
     if (local_gamemission == doom)
     {
         W_AddBaseDir("doom1-all");
@@ -1383,6 +1374,12 @@ static void AutoloadIWadDir(void (*AutoLoadFunc)(const char *path))
                 AutoLoadFunc(dir);
                 free(dir);
             }
+            else if (local_gamemission == pack_chex || local_gamemission == pack_chex3v)
+            {
+                dir = GetAutoloadDir(autoload_paths[i], "chex-all", true);
+                AutoLoadFunc(dir);
+                free(dir);
+            }
 
             if (local_gamemission == doom)
             {
@@ -1584,7 +1581,7 @@ static void D_ShowEndDoom(void)
 
 boolean disable_endoom = false;
 
-static boolean AllowEndDoom(void)
+boolean D_AllowEndDoom(void)
 {
   return (!disable_endoom
           && (exit_sequence == EXIT_SEQUENCE_FULL
@@ -1594,7 +1591,7 @@ static boolean AllowEndDoom(void)
 static void D_EndDoom(void)
 {
   // Do we even want to show an ENDOOM?
-  if (!AllowEndDoom())
+  if (!D_AllowEndDoom())
   {
     return;
   }
@@ -1614,39 +1611,6 @@ static void D_EndDoom(void)
 // [FG] fast-forward demo to the desired map
 int playback_warp = -1;
 
-// [FG] check for SSG assets
-static boolean CheckHaveSSG (void)
-{
-  const int ssg_sfx[] = {sfx_dshtgn, sfx_dbopn, sfx_dbload, sfx_dbcls};
-  char ssg_sprite[] = "SHT2A0";
-  int i;
-
-  if (gamemode == commercial)
-  {
-    return true;
-  }
-
-  for (i = 0; i < arrlen(ssg_sfx); i++)
-  {
-    if (I_GetSfxLumpNum(&S_sfx[ssg_sfx[i]]) < 0)
-    {
-      return false;
-    }
-  }
-
-  for (i = 'A'; i <= 'J'; i++)
-  {
-    ssg_sprite[4] = i;
-
-    if ((W_CheckNumForName)(ssg_sprite, ns_sprites) < 0)
-    {
-      return false;
-    }
-  }
-
-  return true;
-}
-
 static int mainwadfile;
 
 #define SET_DIR(a, b) \
@@ -2241,6 +2205,12 @@ void D_DoomMain(void)
 
   W_InitMultipleFiles();
 
+  // Always process chex.deh first
+  if (gamemission == pack_chex)
+  {
+    ProcessDehLump(W_GetNumForName("chexdeh"));
+  }
+
   // Check for wolf levels
   haswolflevels = (W_CheckNumForName("map31") >= 0);
 
@@ -2413,9 +2383,6 @@ void D_DoomMain(void)
       I_Printf(VB_INFO, "External statistics registered.");
     }
 
-  // [FG] check for SSG assets
-  have_ssg = CheckHaveSSG();
-
   //!
   // @category game
   //
