@@ -50,7 +50,6 @@ extern  int screenblocks;     // killough 11/98
 
 extern GameMode_t gamemode;
 extern GameMission_t gamemission;
-extern GameVariant_t gamevariant;
 
 // [FG] emulate a specific version of Doom
 extern GameVersion_t gameversion;
@@ -64,12 +63,13 @@ typedef struct
 
 extern GameVersions_t gameversions[];
 
-extern char *MAPNAME(int e, int m);
+extern char *MapName(int e, int m);
 
 // Set if homebrew PWAD stuff has been added.
 extern  boolean modifiedgame;
 
 extern boolean have_ssg;
+#define ALLOW_SSG (gamemode == commercial || CRITICAL(have_ssg))
 
 // compatibility with old engines (monster behavior, metrics, etc.)
 extern int compatibility, default_compatibility;          // killough 1/31/98
@@ -93,31 +93,36 @@ typedef struct {
 
 extern overflow_t overflow[EMU_TOTAL];
 
-extern int demo_version;           // killough 7/19/98: Version of demo
+typedef enum {
+  DV_NONE    = -1,
+  DV_VANILLA = 109,
+  DV_LONGTIC = 111,
+  DV_BOOM200 = 200,
+  DV_BOOM201 = 201,
+  DV_BOOM    = 202,
+  DV_MBF     = 203,
+  DV_MBF21   = 221,
+  DV_UM      = 255,
+} demo_version_t;
+
+extern demo_version_t demo_version;           // killough 7/19/98: Version of demo
 
 // Only true when playing back an old demo -- used only in "corner cases"
 // which break playback but are otherwise unnoticable or are just desirable:
 
-#define demo_compatibility (demo_version < 200) /* killough 11/98: macroized */
+#define demo_compatibility (demo_version < DV_BOOM200) /* killough 11/98: macroized */
 
-#define mbf21 (demo_version == 221)
+#define mbf21 (demo_version == DV_MBF21)
 
 // killough 7/19/98: whether monsters should fight against each other
-extern int monster_infighting, default_monster_infighting;
+extern boolean monster_infighting, default_monster_infighting;
 
-extern int monkeys, default_monkeys;
+extern boolean monkeys, default_monkeys;
 
 // v1.1-like pitched sounds
-extern int pitched_sounds;
+extern boolean pitched_sounds;
 
-extern int translucency;
-
-enum {
-  TRANSLUCENCY_OFF,
-  TRANSLUCENCY_WALLS,
-  TRANSLUCENCY_THINGS,
-  TRANSLUCENCY_ALL
-};
+extern boolean translucency;
 
 extern int demo_insurance;      // killough 4/5/98
 
@@ -162,15 +167,6 @@ enum {
 
 extern int comp[COMP_TOTAL], default_comp[COMP_TOTAL];
 
-typedef enum
-{
-  INVUL_VANILLA,
-  INVUL_MBF,
-  INVUL_GRAY,
-} invul_mode_t;
-
-extern invul_mode_t invul_mode;
-
 // -------------------------------------------
 // Language.
 extern  Language_t   language;
@@ -246,7 +242,6 @@ typedef enum
 } overlay_t;
 
 extern  overlay_t automapoverlay;
-extern  boolean automaprotate;
 
 #define automap_on (automapactive && !automapoverlay)
 #define automap_off (!automapactive || automapoverlay)
@@ -298,6 +293,9 @@ extern  boolean lowres_turn;
 // Config key for low resolution turning.
 extern  boolean shorttics;
 
+// Fake longtics when using shorttics.
+extern  boolean fake_longtics;
+
 // cph's doom 1.91 longtics hack
 extern  boolean longtics;
 
@@ -366,7 +364,7 @@ extern wbstartstruct_t wminfo;
 
 // File handling stuff.
 extern  char   *basedefault;
-extern  boolean organize_savefiles;
+extern  int    organize_savefiles;
 
 // if true, load all graphics at level load
 extern  boolean precache;
@@ -375,11 +373,6 @@ extern  boolean precache;
 //  to force a wipe on the next draw
 extern  gamestate_t     wipegamestate;
 
-extern  int             mouseSensitivity_horiz; // killough
-extern  int             mouseSensitivity_vert;
-extern  int             mouseSensitivity_horiz_strafe; // [FG] strafe
-extern  int             mouseSensitivity_vert_look; // [FG] look
-
 // debug flag to cancel adaptiveness
 extern  boolean         singletics;
 
@@ -405,44 +398,38 @@ extern int default_allow_pushers;
 extern int variable_friction;  // ice & mud            // phares 3/10/98
 extern int default_variable_friction;
 
-extern int monsters_remember;                          // killough 3/1/98
-extern int default_monsters_remember;
+extern boolean monsters_remember;                          // killough 3/1/98
+extern boolean default_monsters_remember;
 
-extern int weapon_recoil;          // weapon recoil    // phares
-extern int default_weapon_recoil;
+extern boolean weapon_recoil;          // weapon recoil    // phares
+extern boolean default_weapon_recoil;
 
-extern int player_bobbing;  // whether player bobs or not   // phares 2/25/98
-extern int default_player_bobbing;  // killough 3/1/98: make local to each game
+extern boolean player_bobbing;  // whether player bobs or not   // phares 2/25/98
+extern boolean default_player_bobbing;  // killough 3/1/98: make local to each game
 
 // killough 7/19/98: Classic Pre-Beta BFG
-extern int classic_bfg, default_classic_bfg;
+extern boolean classic_bfg, default_classic_bfg;
 
 // killough 7/24/98: Emulation of Press Release version of Doom
 extern int beta_emulation;
 
 extern int dogs, default_dogs;     // killough 7/19/98: Marine's best friend :)
-extern int dog_jumping, default_dog_jumping;   // killough 10/98
+extern boolean dog_jumping, default_dog_jumping;   // killough 10/98
 
 // killough 8/8/98: distance friendly monsters tend to stay from player
 extern int distfriend, default_distfriend;
 
 // killough 9/8/98: whether monsters are allowed to strafe or retreat
-extern int monster_backing, default_monster_backing;
+extern boolean monster_backing, default_monster_backing;
 
 // killough 9/9/98: whether monsters intelligently avoid hazards
-extern int monster_avoid_hazards, default_monster_avoid_hazards;
+extern boolean monster_avoid_hazards, default_monster_avoid_hazards;
 
 // killough 10/98: whether monsters are affected by friction
-extern int monster_friction, default_monster_friction;
+extern boolean monster_friction, default_monster_friction;
 
 // killough 9/9/98: whether monsters help friends
-extern int help_friends, default_help_friends;
-
-extern boolean pistolstart, default_pistolstart;
-
-extern int flashing_hom; // killough 10/98
-
-extern int doom_weapon_toggles;   // killough 10/98
+extern boolean help_friends, default_help_friends;
 
 extern boolean hide_weapon;
 
