@@ -18,6 +18,8 @@
 #ifndef __I_GLOB__
 #define __I_GLOB__
 
+#include <stddef.h>
+
 #define GLOB_FLAG_NOCASE 0x01
 #define GLOB_FLAG_SORTED 0x02
 
@@ -27,10 +29,14 @@ typedef struct glob_s glob_t;
 // the given glob pattern. I_EndGlob() must be called on completion.
 glob_t *I_StartGlob(const char *directory, const char *glob, int flags);
 
-// Same as I_StartGlob but multiple glob patterns can be provided. The list
-// of patterns must be terminated with NULL.
-glob_t *I_StartMultiGlob(const char *directory, int flags, const char *glob,
-                         ...);
+// Same as I_StartGlob but multiple glob patterns can be provided.
+glob_t *I_StartMultiGlobInternal(const char *directory, int flags,
+                                 const char *glob[], size_t num_globs);
+
+#define I_StartMultiGlob(directory, flags, ...)                               \
+    I_StartMultiGlobInternal(directory, flags, (const char *[]){__VA_ARGS__}, \
+                             sizeof((const char *[]){__VA_ARGS__})            \
+                                 / sizeof(const char *))
 
 // Finish reading file list.
 void I_EndGlob(glob_t *glob);
