@@ -30,13 +30,17 @@
 #include "i_rumble.h"
 #include "i_system.h"
 #include "i_timer.h"
+#include "m_array.h"
 #include "m_config.h"
 #include "m_input.h"
+#include "m_misc.h"
 #include "mn_menu.h"
 
 #define AXIS_BUTTON_DEADZONE (SDL_JOYSTICK_AXIS_MAX / 3)
 
+static const char **gamepad_strings;
 static SDL_GameController *gamepad;
+static SDL_JoystickID gamepad_instance_id = -1;
 static boolean gyro_supported;
 static joy_platform_t platform;
 
@@ -433,6 +437,14 @@ static void I_ShutdownGamepad(void)
     SDL_QuitSubSystem(SDL_INIT_GAMECONTROLLER);
 }
 
+static int NumJoysticks(void)
+{
+    const int num_joysticks = SDL_NumJoysticks();
+    return MAX(0, num_joysticks);
+}
+
+void I_OpenGamepad(int device_index);
+
 void I_InitGamepad(void)
 {
     UpdatePlatform();
@@ -442,6 +454,12 @@ void I_InitGamepad(void)
         return;
     }
 
+#ifdef _WIN32
+    // Raw input is broken for XInput devices under Windows.
+    // https://github.com/libsdl-org/SDL/issues/13047
+    SDL_SetHint(SDL_HINT_JOYSTICK_RAWINPUT, "0");
+#endif
+
     // Enable bluetooth gyro support for DualShock 4 and DualSense.
     SDL_SetHint(SDL_HINT_JOYSTICK_HIDAPI_PS4_RUMBLE, "1");
     SDL_SetHint(SDL_HINT_JOYSTICK_HIDAPI_PS5_RUMBLE, "1");
@@ -460,63 +478,205 @@ void I_InitGamepad(void)
     I_Printf(VB_INFO, "I_InitGamepad: Initialize gamepad.");
 
     I_AtExit(I_ShutdownGamepad, true);
-}
 
-void I_OpenGamepad(int which)
-{
-    if (gamepad)
+    if (joy_device > 0)
     {
-        return;
+        const int num_joysticks = NumJoysticks();
+
+        if (num_joysticks && SDL_IsGameController(joy_device - 1))
+        {
+            I_OpenGamepad(joy_device - 1);
+        }
+        else
+        {
+            joy_device = 1;
+
+            if (num_joysticks && SDL_IsGameController(0))
+            {
+                I_OpenGamepad(0);
+            }
+            else
+            {
+                MN_UpdateAllGamepadItems();
+            }
+        }
+    }
+    else
+    {
+        MN_UpdateAllGamepadItems();
     }
 
-    if (SDL_IsGameController(which))
-    {
-        gamepad = SDL_GameControllerOpen(which);
-        if (gamepad)
-        {
-            I_Printf(VB_INFO,
-                     "I_OpenGamepad: Found a valid gamepad, named: %s",
-                     SDL_GameControllerName(gamepad));
+    last_joy_device = joy_device;
+    SDL_FlushEvents(SDL_CONTROLLERDEVICEADDED, SDL_CONTROLLERDEVICEREMOVED);
+}
 
-            I_SetRumbleSupported(gamepad);
-            I_ResetGamepad();
-            I_LoadGyroCalibration();
-            UpdatePlatform();
-            EnableGamepadEvents();
-            MN_UpdateAllGamepadItems();
+static boolean CheckActiveGamepad(void)
+{
+    if (gamepad_instance_id != -1)
+    {
+        const int num_joysticks = NumJoysticks();
+
+        for (int i = 0; i < num_joysticks; i++)
+        {
+            if (SDL_JoystickGetDeviceInstanceID(i) == gamepad_instance_id)
+            {
+                joy_device = i + 1;
+                last_joy_device = joy_device;
+                MN_UpdateAllGamepadItems();
+                return true;
+            }
         }
     }
 
-    if (gamepad == NULL)
+    return false;
+}
+
+static void CloseGamepad(void)
+{
+    if (gamepad_instance_id != -1)
     {
-        I_Printf(VB_ERROR,
-                 "I_OpenGamepad: Could not open gamepad %i: %s",
-                 which, SDL_GetError());
+        I_ResetAllRumbleChannels();
+        I_SetRumbleSupported(NULL);
+        SDL_GameControllerClose(gamepad);
+        gamepad = NULL;
+        gamepad_instance_id = -1;
+        joy_device = 0;
+        last_joy_device = joy_device;
+        DisableGamepadEvents();
+        UpdatePlatform();
+        I_ResetGamepad();
     }
 }
 
+void I_OpenGamepad(int device_index)
+{
+    if (CheckActiveGamepad())
+    {
+        // Ignore when already using a gamepad.
+        return;
+    }
+
+    CloseGamepad();
+    gamepad = SDL_GameControllerOpen(device_index);
+
+    if (gamepad)
+    {
+        I_Printf(VB_INFO, "I_OpenGamepad: Found a valid gamepad, named: %s",
+                 SDL_GameControllerName(gamepad));
+
+        gamepad_instance_id =
+            SDL_JoystickInstanceID(SDL_GameControllerGetJoystick(gamepad));
+        joy_device = device_index + 1;
+        last_joy_device = joy_device;
+        I_SetRumbleSupported(gamepad);
+        I_ResetAllRumbleChannels();
+        I_ResetGamepad();
+        UpdatePlatform();
+        EnableGamepadEvents();
+        SDL_GameControllerSetPlayerIndex(gamepad, 0);
+
+        if (gyro_supported)
+        {
+            I_LoadGyroCalibration();
+        }
+    }
+    else
+    {
+        I_Printf(VB_ERROR, "I_OpenGamepad: Could not open gamepad %d: %s",
+                 device_index, SDL_GetError());
+    }
+
+    MN_UpdateAllGamepadItems();
+}
+
 void I_CloseGamepad(SDL_JoystickID instance_id)
 {
-    if (gamepad == NULL)
+    if (gamepad_instance_id != -1)
     {
+        if (instance_id == gamepad_instance_id)
+        {
+            CloseGamepad();
+
+            if (NumJoysticks() && SDL_IsGameController(0))
+            {
+                // Fall back to another detected gamepad.
+                I_OpenGamepad(0);
+                return;
+            }
+        }
+        else if (CheckActiveGamepad())
+        {
+            // Ignore when already using a gamepad.
+            return;
+        }
+    }
+
+    MN_UpdateAllGamepadItems();
+}
+
+void I_UpdateGamepadDevice(boolean gamepad_input)
+{
+    if (gamepad_input && joy_device == 0)
+    {
+        // Prevent accidentally disabling gamepad when it's being used.
+        joy_device = last_joy_device;
         return;
     }
 
-    SDL_JoystickID active_instance_id =
-        SDL_JoystickInstanceID(SDL_GameControllerGetJoystick(gamepad));
+    last_joy_device = joy_device;
+    const int device_index = joy_device - 1;
+    CloseGamepad();
 
-    if (instance_id == active_instance_id)
+    if (device_index >= 0)
+    {
+        I_OpenGamepad(device_index);
+    }
+    else
     {
-        SDL_GameControllerClose(gamepad);
-        gamepad = NULL;
-        I_SetRumbleSupported(NULL);
-        DisableGamepadEvents();
-        UpdatePlatform();
-        I_ResetGamepad();
         MN_UpdateAllGamepadItems();
     }
 }
 
+const char **I_GamepadDeviceList(void)
+{
+    if (!I_GamepadEnabled())
+    {
+        return NULL;
+    }
+
+    array_free(gamepad_strings);
+    array_push(gamepad_strings, "None");
+
+    const int num_joysticks = NumJoysticks();
+    int num_gamepads = 0;
+
+    for (int i = 0; i < num_joysticks; i++)
+    {
+        if (SDL_IsGameController(i))
+        {
+            char *name = M_StringDuplicate(SDL_GameControllerNameForIndex(i));
+            array_push(gamepad_strings, name);
+            num_gamepads++;
+        }
+    }
+
+    if (joy_device > num_gamepads)
+    {
+        for (int i = num_gamepads; i < joy_device; i++)
+        {
+            array_push(gamepad_strings, "None");
+        }
+    }
+
+    return gamepad_strings;
+}
+
+boolean I_GamepadDevices(void)
+{
+    return (array_size(gamepad_strings) > 1
+            && strncmp(gamepad_strings[1], "None", strlen(gamepad_strings[1])));
+}
+
 static uint64_t GetSensorTimeUS(const SDL_ControllerSensorEvent *csensor)
 {
 #if SDL_VERSION_ATLEAST(2, 26, 0)
