@@ -28,30 +28,31 @@
 #include "m_fixed.h"
 #include "p_mobj.h"
 #include "r_main.h"
+#include "sounds.h"
 #include "tables.h"
 
 static boolean force_flip_pan;
 
 static boolean I_MBF_AdjustSoundParams(const mobj_t *listener,
-                                       const mobj_t *source, int chanvol,
-                                       int *vol, int *sep, int *pri)
+                                       const mobj_t *source,
+                                       sfxparams_t *params)
 {
-    fixed_t adx, ady, dist;
+    int adx, ady, dist;
     angle_t angle;
 
     // haleyjd 05/29/06: allow per-channel volume scaling
-    *vol = (snd_SfxVolume * chanvol) / 15;
+    params->volume = snd_SfxVolume * params->volume_scale / 15;
 
-    if (*vol < 1)
+    if (params->volume < 1)
     {
         return false;
     }
-    else if (*vol > 127)
+    else if (params->volume > 127)
     {
-        *vol = 127;
+        params->volume = 127;
     }
 
-    *sep = NORM_SEP;
+    params->separation = NORM_SEP;
 
     if (!source || source == players[displayplayer].mo)
     {
@@ -75,20 +76,28 @@ static boolean I_MBF_AdjustSoundParams(const mobj_t *listener,
 
     if (ady > adx)
     {
-        dist = adx, adx = ady, ady = dist;
+        const int temp = adx;
+        adx = ady;
+        ady = temp;
     }
 
-    dist = adx ? FixedDiv(
-               adx, finesine[(tantoangle[FixedDiv(ady, adx) >> DBITS] + ANG90)
-                             >> ANGLETOFINESHIFT])
-               : 0;
+    if (adx)
+    {
+        const int slope = FixedDiv(ady, adx) >> DBITS;
+        const int angle = tantoangle[slope] >> ANGLETOFINESHIFT;
+        dist = FixedDiv(adx, finecosine[angle]);
+    }
+    else
+    {
+        dist = 0;
+    }
 
     if (!dist) // killough 11/98: handle zero-distance as special case
     {
         return true;
     }
 
-    if (dist > S_CLIPPING_DIST >> FRACBITS)
+    if (dist >= S_CLIPPING_DIST)
     {
         return false;
     }
@@ -107,35 +116,38 @@ static boolean I_MBF_AdjustSoundParams(const mobj_t *listener,
         angle >>= ANGLETOFINESHIFT;
 
         // stereo separation
-        *sep = NORM_SEP - FixedMul(S_STEREO_SWING >> FRACBITS, finesine[angle]);
+        params->separation -= FixedMul(S_STEREO_SWING, finesine[angle]);
     }
 
     // volume calculation
-    if (dist > S_CLOSE_DIST >> FRACBITS)
+    if (dist > S_CLOSE_DIST)
     {
-        *vol = *vol * ((S_CLIPPING_DIST >> FRACBITS) - dist) / S_ATTENUATOR;
+        params->volume =
+            params->volume * (S_CLIPPING_DIST - dist) / S_ATTENUATOR;
     }
 
     // haleyjd 09/27/06: decrease priority with volume attenuation
-    *pri = *pri + (127 - *vol);
+    params->priority += (127 - params->volume);
 
-    if (*pri > 255) // cap to 255
+    if (params->priority > 255) // cap to 255
     {
-        *pri = 255;
+        params->priority = 255;
     }
 
-    return (*vol > 0);
+    return (params->volume > 0);
 }
 
-void I_MBF_UpdateSoundParams(int channel, int volume, int separation)
+static void I_MBF_UpdateSoundParams(int channel, const sfxparams_t *params)
 {
+    int separation = params->separation;
+
     // SoM 7/1/02: forceFlipPan accounted for here
     if (force_flip_pan)
     {
         separation = 254 - separation;
     }
 
-    I_OAL_SetVolume(channel, volume);
+    I_OAL_SetVolume(channel, params->volume);
     I_OAL_SetPan(channel, separation);
 }
 
@@ -165,7 +177,10 @@ const sound_module_t sound_mbf_module =
     NULL,
     I_OAL_StartSound,
     I_OAL_StopSound,
+    I_OAL_PauseSound,
+    I_OAL_ResumeSound,
     I_OAL_SoundIsPlaying,
+    I_OAL_SoundIsPaused,
     I_OAL_ShutdownSound,
     I_OAL_ShutdownModule,
     I_OAL_DeferUpdates,
