@@ -19,6 +19,7 @@
 
 #include <math.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "doomtype.h"
 #include "i_printf.h"
@@ -64,6 +65,7 @@ static int midi_complevel = COMP_STANDARD;
 static int midi_reset_type = RESET_TYPE_GM;
 static int midi_reset_delay = -1;
 static boolean midi_ctf = true;
+static boolean midi_sysex_volume = false;
 static int midi_gain = 100;
 
 static const byte gm_system_on[] =
@@ -93,8 +95,10 @@ static const byte ff_loopEnd[] =
 
 static boolean allow_bank_select;
 
+static boolean channel_used[MIDI_CHANNELS_PER_TRACK];
 static byte channel_volume[MIDI_CHANNELS_PER_TRACK];
 static float volume_factor = 0.0f;
+static uint16_t master_volume;
 
 typedef enum
 {
@@ -186,6 +190,7 @@ static void SendChannelMsgZero(const midi_event_t *event)
     const byte message[] = {event->event_type | event->data.channel.channel,
                             event->data.channel.param1, 0};
     MIDI_SendShortMsg(message, sizeof(message));
+    channel_used[event->data.channel.channel] = true;
 }
 
 static void SendChannelMsg(const midi_event_t *event, boolean use_param2)
@@ -203,6 +208,8 @@ static void SendChannelMsg(const midi_event_t *event, boolean use_param2)
                                 event->data.channel.param1};
         MIDI_SendShortMsg(message, sizeof(message));
     }
+
+    channel_used[event->data.channel.channel] = true;
 }
 
 static void SendControlChange(byte channel, byte number, byte value)
@@ -234,6 +241,7 @@ static void SendProgramChange(byte channel, byte program)
     }
 
     MIDI_SendShortMsg(message, sizeof(message));
+    channel_used[channel] = true;
 }
 
 static void SendBankSelectMSB(byte channel, byte value)
@@ -251,6 +259,7 @@ static void SendBankSelectMSB(byte channel, byte value)
     }
 
     SendControlChange(channel, MIDI_CONTROLLER_BANK_SELECT_MSB, value);
+    channel_used[channel] = true;
 }
 
 static void SendBankSelectLSB(byte channel, byte value)
@@ -274,6 +283,7 @@ static void SendBankSelectLSB(byte channel, byte value)
     }
 
     SendControlChange(channel, MIDI_CONTROLLER_BANK_SELECT_LSB, value);
+    channel_used[channel] = true;
 }
 
 // Writes an RPN message set to NULL (0x7F). Prevents accidental data entry.
@@ -283,6 +293,7 @@ static void SendNullRPN(const midi_event_t *event)
     const byte channel = event->data.channel.channel;
     SendControlChange(channel, MIDI_CONTROLLER_RPN_LSB, MIDI_RPN_NULL);
     SendControlChange(channel, MIDI_CONTROLLER_RPN_MSB, MIDI_RPN_NULL);
+    channel_used[channel] = true;
 }
 
 static void UpdateTempo(const midi_event_t *event)
@@ -292,6 +303,21 @@ static void UpdateTempo(const midi_event_t *event)
     RestartTimer(TicksToUS(song.elapsed_time));
 }
 
+// Writes a master volume message. The value is scaled by the volume slider.
+
+static void SendMasterVolumeMsg(uint16_t volume)
+{
+    uint32_t scaled_volume = lroundf((float)volume * volume_factor);
+    scaled_volume = MIN(scaled_volume, MIDI_DEFAULT_MASTER_VOLUME);
+
+    const byte lsb = scaled_volume & 0x7F;
+    const byte msb = (scaled_volume >> 7) & 0x7F;
+    const byte data[] = {0xF0, 0x7F, 0x7F, 0x04, 0x01, lsb, msb, 0xF7};
+    MIDI_SendLongMsg(data, sizeof(data));
+
+    master_volume = volume;
+}
+
 // Writes a MIDI volume message. The value is scaled by the volume slider.
 
 static void SendManualVolumeMsg(byte channel, byte volume)
@@ -308,19 +334,33 @@ static void SendManualVolumeMsg(byte channel, byte volume)
 
 static void SendVolumeMsg(const midi_event_t *event)
 {
-    SendManualVolumeMsg(event->data.channel.channel,
-                        event->data.channel.param2);
+    if (midi_sysex_volume)
+    {
+        SendChannelMsg(event, true);
+    }
+    else
+    {
+        SendManualVolumeMsg(event->data.channel.channel,
+                            event->data.channel.param2);
+    }
+
+    channel_used[event->data.channel.channel] = true;
 }
 
 // Sets each channel to its saved volume level, scaled by the volume slider.
 
 static void UpdateVolume(void)
 {
-    int i;
-
-    for (i = 0; i < MIDI_CHANNELS_PER_TRACK; ++i)
+    if (midi_sysex_volume)
     {
-        SendManualVolumeMsg(i, channel_volume[i]);
+        SendMasterVolumeMsg(master_volume);
+    }
+    else
+    {
+        for (int i = 0; i < MIDI_CHANNELS_PER_TRACK; i++)
+        {
+            SendManualVolumeMsg(i, channel_volume[i]);
+        }
     }
 }
 
@@ -328,11 +368,16 @@ static void UpdateVolume(void)
 
 static void ResetVolume(void)
 {
-    int i;
-
-    for (i = 0; i < MIDI_CHANNELS_PER_TRACK; ++i)
+    if (midi_sysex_volume)
     {
-        SendManualVolumeMsg(i, MIDI_DEFAULT_VOLUME);
+        SendMasterVolumeMsg(MIDI_DEFAULT_MASTER_VOLUME);
+    }
+    else
+    {
+        for (int i = 0; i < MIDI_CHANNELS_PER_TRACK; i++)
+        {
+            SendManualVolumeMsg(i, MIDI_DEFAULT_VOLUME);
+        }
     }
 }
 
@@ -351,19 +396,6 @@ static void SendNotesSoundOff(void)
     }
 }
 
-// Writes "reset all controllers" message for each channel. Despite the name,
-// this only resets some controllers (see MIDI Recommended Practice RP-015).
-
-static void ResetControllers(void)
-{
-    int i;
-
-    for (i = 0; i < MIDI_CHANNELS_PER_TRACK; i++)
-    {
-        SendControlChange(i, MIDI_CONTROLLER_RESET_ALL_CTRLS, 0);
-    }
-}
-
 // Resets commonly used controllers. This is only for a reset type of "No SysEx"
 // for devices that don't support SysEx resets.
 
@@ -485,6 +517,8 @@ static void ResetDevice(void)
     {
         I_Sleep(midi_reset_delay);
     }
+
+    memset(channel_used, 0, sizeof(channel_used));
 }
 
 static void SendSysExMsg(const midi_event_t *event)
@@ -501,6 +535,44 @@ static void SendSysExMsg(const midi_event_t *event)
             }
             MIDI_SendLongMsg(data, length);
             ResetVolume();
+            memset(channel_used, 0, sizeof(channel_used));
+            break;
+
+        case MIDI_SYSEX_MASTER_VOLUME:
+            if (midi_sysex_volume)
+            {
+                const uint16_t volume =
+                    ((data[6] & 0x7F) << 7) | (data[5] & 0x7F);
+                SendMasterVolumeMsg(volume);
+            }
+            else
+            {
+                MIDI_SendLongMsg(data, length);
+            }
+            break;
+
+        case MIDI_SYSEX_MASTER_VOLUME_ROLAND:
+            if (midi_sysex_volume)
+            {
+                const uint16_t volume = (data[8] & 0x7F) << 7;
+                SendMasterVolumeMsg(volume);
+            }
+            else
+            {
+                MIDI_SendLongMsg(data, length);
+            }
+            break;
+
+        case MIDI_SYSEX_MASTER_VOLUME_YAMAHA:
+            if (midi_sysex_volume)
+            {
+                const uint16_t volume = (data[7] & 0x7F) << 7;
+                SendMasterVolumeMsg(volume);
+            }
+            else
+            {
+                MIDI_SendLongMsg(data, length);
+            }
             break;
 
         case MIDI_SYSEX_RHYTHM_PART:
@@ -515,8 +587,16 @@ static void SendSysExMsg(const midi_event_t *event)
             break;
 
         case MIDI_SYSEX_PART_LEVEL:
-            // Replace SysEx part level message with channel volume message.
-            SendManualVolumeMsg(event->data.sysex.channel, data[8]);
+            if (midi_sysex_volume)
+            {
+                MIDI_SendLongMsg(data, length);
+            }
+            else
+            {
+                // Replace SysEx part level message with channel volume message.
+                SendManualVolumeMsg(event->data.sysex.channel, data[8]);
+            }
+            channel_used[event->data.sysex.channel] = true;
             break;
     }
 }
@@ -965,6 +1045,37 @@ static void RestartLoop(void)
     RestartTimer(TicksToUS(song.elapsed_time));
 }
 
+// Resets the controllers and volume for each channel, similar to vanilla Doom.
+
+static void ResetControllersVolume(void)
+{
+    if (midi_sysex_volume)
+    {
+        for (int i = 0; i < MIDI_CHANNELS_PER_TRACK; i++)
+        {
+            if (channel_used[i])
+            {
+                SendControlChange(i, MIDI_CONTROLLER_RESET_ALL_CTRLS, 0);
+                SendControlChange(i, MIDI_CONTROLLER_VOLUME_MSB,
+                                  MIDI_DEFAULT_VOLUME);
+                channel_used[i] = false;
+            }
+        }
+    }
+    else
+    {
+        for (int i = 0; i < MIDI_CHANNELS_PER_TRACK; i++)
+        {
+            if (channel_used[i])
+            {
+                SendControlChange(i, MIDI_CONTROLLER_RESET_ALL_CTRLS, 0);
+                SendManualVolumeMsg(i, MIDI_DEFAULT_VOLUME);
+                channel_used[i] = false;
+            }
+        }
+    }
+}
+
 // Restarts a song that uses standard looping.
 
 static void RestartTracks(void)
@@ -1020,8 +1131,7 @@ static midi_state_t NextEvent(midi_position_t *position)
             }
             else if (song.looping)
             {
-                ResetControllers();
-                ResetVolume();
+                ResetControllersVolume();
                 RestartTracks();
                 return STATE_PLAYING;
             }
@@ -1508,6 +1618,8 @@ static void I_MID_BindVariables(void)
         "[Native MIDI] Delay after reset (-1 = Auto; 0 = None; 1-2000 = Milliseconds)");
     BIND_BOOL(midi_ctf, true,
         "[Native MIDI] Fix invalid instruments by emulating SC-55 capital tone fallback");
+    BIND_BOOL(midi_sysex_volume, false,
+        "[Native MIDI] Use SysEx messages to control volume");
     BIND_NUM(midi_gain, 0, -20, 0, "[Native MIDI] Gain [dB]");
 }
 
