@@ -29,7 +29,7 @@
 
 // when to clip out sounds
 // Does not fit the large outdoor areas.
-#define S_CLIPPING_DIST (1200 << FRACBITS)
+#define S_CLIPPING_DIST 1200
 
 // Distance to origin when sounds should be maxed out.
 // This should relate to movement clipping resolution
@@ -39,9 +39,9 @@
 // killough 12/98: restore original
 // #define S_CLOSE_DIST (160<<FRACBITS)
 
-#define S_CLOSE_DIST    (200 << FRACBITS)
+#define S_CLOSE_DIST    200
 
-#define S_ATTENUATOR    ((S_CLIPPING_DIST - S_CLOSE_DIST) >> FRACBITS)
+#define S_ATTENUATOR    (S_CLIPPING_DIST - S_CLOSE_DIST)
 
 // Adjustable by menu.
 // [FG] moved here from i_sound.c
@@ -50,7 +50,7 @@
 #define NORM_PITCH      128
 #define NORM_PRIORITY   64
 #define NORM_SEP        128
-#define S_STEREO_SWING  (96 << FRACBITS)
+#define S_STEREO_SWING  96
 
 #define SND_SAMPLERATE  44100
 
@@ -65,8 +65,8 @@ void I_ShutdownSound(void);
 //
 
 struct mobj_s;
-
 struct sfxinfo_s;
+struct sfxparams_s;
 
 typedef struct sound_module_s
 {
@@ -75,13 +75,16 @@ typedef struct sound_module_s
     boolean (*AllowReinitSound)(void);
     boolean (*CacheSound)(struct sfxinfo_s *sfx);
     boolean (*AdjustSoundParams)(const struct mobj_s *listener,
-                                 const struct mobj_s *source, int chanvol,
-                                 int *vol, int *sep, int *pri);
-    void (*UpdateSoundParams)(int channel, int vol, int sep);
+                                 const struct mobj_s *source,
+                                 struct sfxparams_s *params);
+    void (*UpdateSoundParams)(int channel, const struct sfxparams_s *params);
     void (*UpdateListenerParams)(const struct mobj_s *listener);
     boolean (*StartSound)(int channel, struct sfxinfo_s *sfx, float pitch);
     void (*StopSound)(int channel);
+    void (*PauseSound)(int channel);
+    void (*ResumeSound)(int channel);
     boolean (*SoundIsPlaying)(int channel);
+    boolean (*SoundIsPaused)(int channel);
     void (*ShutdownSound)(void);
     void (*ShutdownModule)(void);
     void (*DeferUpdates)(void);
@@ -113,32 +116,34 @@ void I_SetChannels(void);
 int I_GetSfxLumpNum(struct sfxinfo_s *sfxinfo);
 
 // Starts a sound in a particular sound channel.
-int I_StartSound(struct sfxinfo_s *sound, int vol, int sep, int pitch);
+int I_StartSound(struct sfxinfo_s *sound, const struct sfxparams_s *params,
+                 int pitch);
 
 // Stops a sound channel.
 void I_StopSound(int handle);
 
+void I_PauseSound(int handle);
+void I_ResumeSound(int handle);
+
 // Called by S_*() functions
 //  to see if a channel is still playing.
 // Returns 0 if no longer playing, 1 if playing.
 boolean I_SoundIsPlaying(int handle);
+boolean I_SoundIsPaused(int handle);
 
 // Outputs adjusted volume, separation, and priority from the sound module.
 // Returns false if no sound should be played.
 boolean I_AdjustSoundParams(const struct mobj_s *listener,
-                            const struct mobj_s *source, int chanvol, int *vol,
-                            int *sep, int *pri);
+                            const struct mobj_s *source,
+                            struct sfxparams_s *params);
 
 // Updates the volume, separation,
 //  and pitch of a sound channel.
-void I_UpdateSoundParams(int handle, int vol, int sep);
+void I_UpdateSoundParams(int handle, const struct sfxparams_s *params);
 void I_UpdateListenerParams(const struct mobj_s *listener);
 void I_DeferSoundUpdates(void);
 void I_ProcessSoundUpdates(void);
 
-// haleyjds
-int I_SoundID(int handle);
-
 //
 //  MUSIC I/O
 //
