@@ -51,7 +51,4 @@ char *M_getenv(const char *name);
 char *M_ConvertWideToUtf8(const wchar_t *wstr);
 #endif
 
-char *M_ConvertSysNativeMBToUtf8(const char *str);
-char *M_ConvertUtf8ToSysNativeMB(const char *str);
-
 #endif // M_IO_INCLUDED
