@@ -41,6 +41,8 @@ boolean M_StringCopy(char *dest, const char *src, size_t dest_size);
 boolean M_StringConcat(char *dest, const char *src, size_t dest_size);
 char *M_StringReplace(const char *haystack, const char *needle,
                       const char *replacement);
+char *M_StringReplaceWord(const char *haystack, const char *needle,
+                          const char *replacement);
 
 char *M_StringJoinInternal(const char *s[], size_t n);
 #define M_StringJoin(...)                                      \
