@@ -14,9 +14,9 @@
 // Common code shared between the client and server
 //
 
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 
 #include "doomtype.h"
 #include "i_system.h"
@@ -33,7 +33,7 @@
 
 // maximum time between sending packets
 
-#define KEEPALIVE_PERIOD 1
+#define KEEPALIVE_PERIOD       1
 
 // reliable packet that is guaranteed to reach its destination
 
@@ -88,20 +88,21 @@ void NET_Conn_SendPacket(net_connection_t *conn, net_packet_t *packet)
     NET_SendPacket(conn->addr, packet);
 }
 
-static void NET_Conn_ParseDisconnect(net_connection_t *conn, net_packet_t *packet)
+static void NET_Conn_ParseDisconnect(net_connection_t *conn,
+                                     net_packet_t *packet)
 {
     net_packet_t *reply;
 
     // Other end wants to disconnect
     // Send a DISCONNECT_ACK reply.
-    
+
     reply = NET_NewPacket(10);
     NET_WriteInt16(reply, NET_PACKET_TYPE_DISCONNECT_ACK);
     NET_Conn_SendPacket(conn, reply);
     NET_FreePacket(reply);
 
     conn->last_send_time = I_GetTimeMS();
-    
+
     conn->state = NET_CONN_STATE_DISCONNECTED_SLEEP;
     conn->disconnect_reason = NET_DISCONNECT_REMOTE;
 }
@@ -116,14 +117,15 @@ static void NET_Conn_ParseDisconnectACK(net_connection_t *conn,
     {
         // We have received an acknowledgement to our disconnect
         // request. We have been disconnected successfully.
-        
+
         conn->state = NET_CONN_STATE_DISCONNECTED;
         conn->disconnect_reason = NET_DISCONNECT_LOCAL;
         conn->last_send_time = -1;
     }
 }
 
-static void NET_Conn_ParseReliableACK(net_connection_t *conn, net_packet_t *packet)
+static void NET_Conn_ParseReliableACK(net_connection_t *conn,
+                                      net_packet_t *packet)
 {
     unsigned int seq;
 
@@ -136,7 +138,7 @@ static void NET_Conn_ParseReliableACK(net_connection_t *conn, net_packet_t *pack
     {
         return;
     }
-            
+
     // Is this an acknowledgement for the first packet in the list?
 
     if (seq == (unsigned int)((conn->reliable_packets->seq + 1) & 0xff))
@@ -148,7 +150,7 @@ static void NET_Conn_ParseReliableACK(net_connection_t *conn, net_packet_t *pack
 
         rp = conn->reliable_packets;
         conn->reliable_packets = rp->next;
-        
+
         NET_FreePacket(rp->packet);
         free(rp);
     }
@@ -158,7 +160,7 @@ static void NET_Conn_ParseReliableACK(net_connection_t *conn, net_packet_t *pack
 //
 // Returns true if the packet should be discarded (incorrect sequence)
 
-static boolean NET_Conn_ReliablePacket(net_connection_t *conn, 
+static boolean NET_Conn_ReliablePacket(net_connection_t *conn,
                                        net_packet_t *packet)
 {
     unsigned int seq;
@@ -186,13 +188,13 @@ static boolean NET_Conn_ReliablePacket(net_connection_t *conn,
         // Now we can receive the next packet in the sequence.
 
         conn->reliable_recv_seq = (conn->reliable_recv_seq + 1) & 0xff;
-    
+
         result = false;
     }
 
     // Send an acknowledgement
 
-    // Note: this is braindead.  It would be much more sensible to 
+    // Note: this is braindead.  It would be much more sensible to
     // include this in the next packet, rather than the overhead of
     // sending a complete packet just for one byte of information.
 
@@ -212,7 +214,7 @@ static boolean NET_Conn_ReliablePacket(net_connection_t *conn,
 //
 // Returns true if eaten by common code
 
-boolean NET_Conn_Packet(net_connection_t *conn, net_packet_t *packet, 
+boolean NET_Conn_Packet(net_connection_t *conn, net_packet_t *packet,
                         unsigned int *packet_type)
 {
     conn->keepalive_recv_time = I_GetTimeMS();
@@ -221,7 +223,7 @@ boolean NET_Conn_Packet(net_connection_t *conn, net_packet_t *packet,
 
     if (*packet_type & NET_RELIABLE_PACKET)
     {
-        if (NET_Conn_ReliablePacket(conn, packet)) 
+        if (NET_Conn_ReliablePacket(conn, packet))
         {
             // Invalid packet: eat it.
 
@@ -232,7 +234,7 @@ boolean NET_Conn_Packet(net_connection_t *conn, net_packet_t *packet,
 
         *packet_type &= ~NET_RELIABLE_PACKET;
     }
-    
+
     switch (*packet_type)
     {
         case NET_PACKET_TYPE_DISCONNECT:
@@ -261,8 +263,8 @@ boolean NET_Conn_Packet(net_connection_t *conn, net_packet_t *packet,
 void NET_Conn_Disconnect(net_connection_t *conn)
 {
     if (conn->state != NET_CONN_STATE_DISCONNECTED
-     && conn->state != NET_CONN_STATE_DISCONNECTING
-     && conn->state != NET_CONN_STATE_DISCONNECTED_SLEEP)
+        && conn->state != NET_CONN_STATE_DISCONNECTING
+        && conn->state != NET_CONN_STATE_DISCONNECTED_SLEEP)
     {
         conn->state = NET_CONN_STATE_DISCONNECTING;
         conn->disconnect_reason = NET_DISCONNECT_LOCAL;
@@ -290,7 +292,7 @@ void NET_Conn_Run(net_connection_t *conn)
             conn->state = NET_CONN_STATE_DISCONNECTED;
             conn->disconnect_reason = NET_DISCONNECT_TIMEOUT;
         }
-        
+
         if (nowtime - conn->keepalive_send_time > KEEPALIVE_PERIOD * 1000)
         {
             // We have not sent anything in a long time.
@@ -308,8 +310,8 @@ void NET_Conn_Run(net_connection_t *conn)
         // NB.  This is braindead, we have a fixed time of one second.
 
         if (conn->reliable_packets != NULL
-         && (conn->reliable_packets->last_send_time < 0
-          || nowtime - conn->reliable_packets->last_send_time > 1000))
+            && (conn->reliable_packets->last_send_time < 0
+                || nowtime - conn->reliable_packets->last_send_time > 1000))
         {
             // Packet timed out, time to resend
 
@@ -321,10 +323,9 @@ void NET_Conn_Run(net_connection_t *conn)
     {
         // Waiting for a reply to our DISCONNECT request.
 
-        if (conn->last_send_time < 0
-         || nowtime - conn->last_send_time > 1000)
+        if (conn->last_send_time < 0 || nowtime - conn->last_send_time > 1000)
         {
-            // it has been a second since the last disconnect packet 
+            // it has been a second since the last disconnect packet
             // was sent, and still no reply.
 
             if (conn->num_retries < MAX_RETRIES)
@@ -339,7 +340,7 @@ void NET_Conn_Run(net_connection_t *conn)
 
                 ++conn->num_retries;
             }
-            else 
+            else
             {
                 // No more retries allowed.
                 // Force disconnect.
@@ -377,7 +378,7 @@ net_packet_t *NET_Conn_NewReliable(net_connection_t *conn, int packet_type)
     NET_WriteInt16(packet, packet_type | NET_RELIABLE_PACKET);
 
     // write the low byte of the send sequence number
-    
+
     NET_WriteInt8(packet, conn->reliable_send_seq & 0xff);
 
     // Add to the list of reliable packets
@@ -388,9 +389,9 @@ net_packet_t *NET_Conn_NewReliable(net_connection_t *conn, int packet_type)
     rp->seq = conn->reliable_send_seq;
     rp->last_send_time = -1;
 
-    for (listend = &conn->reliable_packets; 
-         *listend != NULL; 
-         listend = &((*listend)->next));
+    for (listend = &conn->reliable_packets; *listend != NULL;
+         listend = &((*listend)->next))
+        ;
 
     *listend = rp;
 
@@ -399,11 +400,11 @@ net_packet_t *NET_Conn_NewReliable(net_connection_t *conn, int packet_type)
     conn->reliable_send_seq = (conn->reliable_send_seq + 1) & 0xff;
 
     // Finished
-    
+
     return packet;
 }
 
-// Used to expand the least significant byte of a tic number into 
+// Used to expand the least significant byte of a tic number into
 // the full tic number, from the current tic number
 
 unsigned int NET_ExpandTicNum(unsigned int relative, unsigned int b)
@@ -417,10 +418,14 @@ unsigned int NET_ExpandTicNum(unsigned int relative, unsigned int b)
     result = h | b;
 
     if (l < 0x40 && b > 0xb0)
+    {
         result -= 0x100;
+    }
     if (l > 0xb0 && b < 0x40)
+    {
         result += 0x100;
-    
+    }
+
     return result;
 }
 
@@ -430,16 +435,24 @@ boolean NET_ValidGameSettings(GameMode_t mode, GameMission_t mission,
                               net_gamesettings_t *settings)
 {
     if (settings->ticdup <= 0)
+    {
         return false;
+    }
 
     if (settings->extratics < 0)
+    {
         return false;
+    }
 
     if (settings->deathmatch < 0 || settings->deathmatch > 3)
+    {
         return false;
+    }
 
     if (settings->skill < sk_none || settings->skill > sk_nightmare)
+    {
         return false;
+    }
 #if 0
     if (!D_ValidGameVersion(mission, settings->gameversion))
         return false;
@@ -520,4 +533,3 @@ void NET_LogPacket(net_packet_t *packet)
     }
     fprintf(net_debug, "\n");
 }
-
