@@ -21,7 +21,7 @@
 #include "doomtype.h"
 #include "i_system.h"
 #include "m_argv.h"
-#include "m_misc2.h"
+#include "m_misc.h"
 #include "net_defs.h"
 #include "net_io.h"
 #include "net_packet.h"
@@ -56,15 +56,13 @@ static void NET_SDL_InitAddrTable(void)
 {
     addr_table_size = 16;
 
-    addr_table = Z_Malloc(sizeof(addrpair_t *) * addr_table_size,
-                          PU_STATIC, 0);
+    addr_table = Z_Malloc(sizeof(addrpair_t *) * addr_table_size, PU_STATIC, 0);
     memset(addr_table, 0, sizeof(addrpair_t *) * addr_table_size);
 }
 
 static boolean AddressesEqual(IPaddress *a, IPaddress *b)
 {
-    return a->host == b->host
-        && a->port == b->port;
+    return a->host == b->host && a->port == b->port;
 }
 
 // Finds an address by searching the table.  If the address is not found,
@@ -81,16 +79,18 @@ static net_addr_t *NET_SDL_FindAddress(IPaddress *addr)
         NET_SDL_InitAddrTable();
     }
 
-    for (i=0; i<addr_table_size; ++i)
+    for (i = 0; i < addr_table_size; ++i)
     {
         if (addr_table[i] != NULL
-         && AddressesEqual(addr, &addr_table[i]->sdl_addr))
+            && AddressesEqual(addr, &addr_table[i]->sdl_addr))
         {
             return &addr_table[i]->net_addr;
         }
 
         if (empty_entry < 0 && addr_table[i] == NULL)
+        {
             empty_entry = i;
+        }
     }
 
     // Was not found in list.  We need to add it.
@@ -106,15 +106,15 @@ static net_addr_t *NET_SDL_FindAddress(IPaddress *addr)
         // in the new block of memory
 
         empty_entry = addr_table_size;
-        
-        // allocate a new array twice the size, init to 0 and copy 
+
+        // allocate a new array twice the size, init to 0 and copy
         // the existing table in.  replace the old table.
 
         new_addr_table_size = addr_table_size * 2;
-        new_addr_table = Z_Malloc(sizeof(addrpair_t *) * new_addr_table_size,
-                                  PU_STATIC, 0);
+        new_addr_table =
+            Z_Malloc(sizeof(addrpair_t *) * new_addr_table_size, PU_STATIC, 0);
         memset(new_addr_table, 0, sizeof(addrpair_t *) * new_addr_table_size);
-        memcpy(new_addr_table, addr_table, 
+        memcpy(new_addr_table, addr_table,
                sizeof(addrpair_t *) * addr_table_size);
         Z_Free(addr_table);
         addr_table = new_addr_table;
@@ -122,7 +122,7 @@ static net_addr_t *NET_SDL_FindAddress(IPaddress *addr)
     }
 
     // Add a new entry
-    
+
     new_entry = Z_Malloc(sizeof(addrpair_t), PU_STATIC, 0);
 
     new_entry->sdl_addr = *addr;
@@ -138,8 +138,8 @@ static net_addr_t *NET_SDL_FindAddress(IPaddress *addr)
 static void NET_SDL_FreeAddress(net_addr_t *addr)
 {
     int i;
-    
-    for (i=0; i<addr_table_size; ++i)
+
+    for (i = 0; i < addr_table_size; ++i)
     {
         if (addr == &addr_table[i]->net_addr)
         {
@@ -157,19 +157,23 @@ static boolean NET_SDL_InitClient(void)
     int p;
 
     if (initted)
+    {
         return true;
+    }
 
     //!
     // @category net
     // @arg <n>
     //
-    // Use the specified UDP port for communications, instead of 
+    // Use the specified UDP port for communications, instead of
     // the default (2342).
     //
 
     p = M_CheckParmWithArgs("-port", 1);
     if (p > 0)
+    {
         port = M_ParmArgToInt(p);
+    }
 
     if (SDLNet_Init() < 0)
     {
@@ -183,7 +187,7 @@ static boolean NET_SDL_InitClient(void)
     {
         I_Error("NET_SDL_InitClient: Unable to open a socket!");
     }
-    
+
     recvpacket = SDLNet_AllocPacket(1500);
 
 #ifdef DROP_PACKETS
@@ -200,11 +204,15 @@ static boolean NET_SDL_InitServer(void)
     int p;
 
     if (initted)
+    {
         return true;
+    }
 
     p = M_CheckParmWithArgs("-port", 1);
     if (p > 0)
-        port = atoi(myargv[p+1]);
+    {
+        port = atoi(myargv[p + 1]);
+    }
 
     if (SDLNet_Init() < 0)
     {
@@ -233,7 +241,7 @@ static void NET_SDL_SendPacket(net_addr_t *addr, net_packet_t *packet)
 {
     UDPpacket sdl_packet;
     IPaddress ip;
-   
+
     if (addr == &net_broadcast_addr)
     {
         SDLNet_ResolveHost(&ip, NULL, port);
@@ -241,7 +249,7 @@ static void NET_SDL_SendPacket(net_addr_t *addr, net_packet_t *packet)
     }
     else
     {
-        ip = *((IPaddress *) addr->handle);
+        ip = *((IPaddress *)addr->handle);
     }
 
 #if 0
@@ -262,7 +270,9 @@ static void NET_SDL_SendPacket(net_addr_t *addr, net_packet_t *packet)
 
 #ifdef DROP_PACKETS
     if ((rand() % 4) == 0)
+    {
         return;
+    }
 #endif
 
     sdl_packet.channel = 0;
@@ -292,7 +302,9 @@ static boolean NET_SDL_RecvPacket(net_addr_t **addr, net_packet_t **packet)
     // no packets received
 
     if (result == 0)
+    {
         return false;
+    }
 
     // Put the data into a new packet structure
 
@@ -313,13 +325,12 @@ void NET_SDL_AddrToString(net_addr_t *addr, char *buffer, int buffer_len)
     uint32_t host;
     uint16_t port;
 
-    ip = (IPaddress *) addr->handle;
+    ip = (IPaddress *)addr->handle;
     host = SDLNet_Read32(&ip->host);
     port = SDLNet_Read16(&ip->port);
 
-    M_snprintf(buffer, buffer_len, "%i.%i.%i.%i",
-               (host >> 24) & 0xff, (host >> 16) & 0xff,
-               (host >> 8) & 0xff, host & 0xff);
+    M_snprintf(buffer, buffer_len, "%i.%i.%i.%i", (host >> 24) & 0xff,
+               (host >> 16) & 0xff, (host >> 8) & 0xff, host & 0xff);
 
     // If we are using the default port we just need to show the IP address,
     // but otherwise we need to include the port. This is important because
@@ -346,14 +357,14 @@ net_addr_t *NET_SDL_ResolveAddress(const char *address)
     addr_hostname = M_StringDuplicate(address);
     if (colon != NULL)
     {
-	addr_hostname[colon - address] = '\0';
-	addr_port = atoi(colon + 1);
+        addr_hostname[colon - address] = '\0';
+        addr_port = atoi(colon + 1);
     }
     else
     {
-	addr_port = port;
+        addr_port = port;
     }
-    
+
     result = SDLNet_ResolveHost(&ip, addr_hostname, addr_port);
 
     free(addr_hostname);
@@ -373,7 +384,9 @@ net_addr_t *NET_SDL_ResolveAddress(const char *address)
 void NET_SDL_Shutdown(void)
 {
     if (!initted)
+    {
         return;
+    }
 
     SDLNet_Quit();
 }
@@ -391,4 +404,3 @@ net_module_t net_sdl_module =
     NET_SDL_ResolveAddress,
     NET_SDL_Shutdown,
 };
-
