@@ -18,7 +18,7 @@
 
 #include "doomtype.h"
 #include "i_system.h"
-#include "m_misc2.h"
+#include "m_misc.h"
 #include "net_packet.h"
 #include "net_structrw.h"
 
@@ -47,15 +47,15 @@ void NET_WriteConnectData(net_packet_t *packet, net_connect_data_t *data)
 
 boolean NET_ReadConnectData(net_packet_t *packet, net_connect_data_t *data)
 {
-    return NET_ReadInt8(packet, (unsigned int *) &data->gamemode)
-        && NET_ReadInt8(packet, (unsigned int *) &data->gamemission)
-        && NET_ReadInt8(packet, (unsigned int *) &data->lowres_turn)
-        && NET_ReadInt8(packet, (unsigned int *) &data->drone)
-        && NET_ReadInt8(packet, (unsigned int *) &data->max_players)
-        && NET_ReadInt8(packet, (unsigned int *) &data->is_freedoom)
-        && NET_ReadSHA1Sum(packet, data->wad_sha1sum)
-        && NET_ReadSHA1Sum(packet, data->deh_sha1sum)
-        && NET_ReadInt8(packet, (unsigned int *) &data->player_class);
+    return NET_ReadInt8(packet, (unsigned int *)&data->gamemode)
+           && NET_ReadInt8(packet, (unsigned int *)&data->gamemission)
+           && NET_ReadInt8(packet, (unsigned int *)&data->lowres_turn)
+           && NET_ReadInt8(packet, (unsigned int *)&data->drone)
+           && NET_ReadInt8(packet, (unsigned int *)&data->max_players)
+           && NET_ReadInt8(packet, (unsigned int *)&data->is_freedoom)
+           && NET_ReadSHA1Sum(packet, data->wad_sha1sum)
+           && NET_ReadSHA1Sum(packet, data->deh_sha1sum)
+           && NET_ReadInt8(packet, (unsigned int *)&data->player_class);
 }
 
 void NET_WriteSettings(net_packet_t *packet, net_gamesettings_t *settings)
@@ -97,23 +97,23 @@ boolean NET_ReadSettings(net_packet_t *packet, net_gamesettings_t *settings)
     boolean success;
     int i;
 
-    success = NET_ReadInt8(packet, (unsigned int *) &settings->ticdup)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->extratics)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->deathmatch)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->nomonsters)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->fast_monsters)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->respawn_monsters)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->episode)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->map)
+    success = NET_ReadInt8(packet, (unsigned int *)&settings->ticdup)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->extratics)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->deathmatch)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->nomonsters)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->fast_monsters)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->respawn_monsters)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->episode)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->map)
            && NET_ReadSInt8(packet, &settings->skill)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->gameversion)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->lowres_turn)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->new_sync)
-           && NET_ReadInt32(packet, (unsigned int *) &settings->timelimit)
-           && NET_ReadSInt8(packet, (signed int *) &settings->loadgame)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->random)
-           && NET_ReadInt8(packet, (unsigned int *) &settings->num_players)
-           && NET_ReadSInt8(packet, (signed int *) &settings->consoleplayer);
+           && NET_ReadInt8(packet, (unsigned int *)&settings->gameversion)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->lowres_turn)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->new_sync)
+           && NET_ReadInt32(packet, (unsigned int *)&settings->timelimit)
+           && NET_ReadSInt8(packet, (signed int *)&settings->loadgame)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->random)
+           && NET_ReadInt8(packet, (unsigned int *)&settings->num_players)
+           && NET_ReadSInt8(packet, (signed int *)&settings->consoleplayer);
 
     if (!success)
     {
@@ -122,21 +122,20 @@ boolean NET_ReadSettings(net_packet_t *packet, net_gamesettings_t *settings)
 
     for (i = 0; i < settings->num_players && i < NET_MAXPLAYERS; ++i)
     {
-        if (!NET_ReadInt8(packet,
-                          (unsigned int *) &settings->player_classes[i]))
+        if (!NET_ReadInt8(packet, (unsigned int *)&settings->player_classes[i]))
         {
             return false;
         }
     }
 
-    NET_ReadInt8(packet, (unsigned int *) &settings->demo_version);
+    NET_ReadInt8(packet, (unsigned int *)&settings->demo_version);
 
     for (i = 0; i < NET_GAME_OPTION_SIZE; ++i)
     {
         unsigned int value;
         if (NET_ReadInt8(packet, &value))
         {
-            settings->options[i] = (byte) value;
+            settings->options[i] = (byte)value;
         }
     }
 
@@ -150,11 +149,11 @@ boolean NET_ReadQueryData(net_packet_t *packet, net_querydata_t *query)
     query->version = NET_ReadSafeString(packet);
 
     success = query->version != NULL
-          && NET_ReadInt8(packet, (unsigned int *) &query->server_state)
-          && NET_ReadInt8(packet, (unsigned int *) &query->num_players)
-          && NET_ReadInt8(packet, (unsigned int *) &query->max_players)
-          && NET_ReadInt8(packet, (unsigned int *) &query->gamemode)
-          && NET_ReadInt8(packet, (unsigned int *) &query->gamemission);
+           && NET_ReadInt8(packet, (unsigned int *)&query->server_state)
+           && NET_ReadInt8(packet, (unsigned int *)&query->num_players)
+           && NET_ReadInt8(packet, (unsigned int *)&query->max_players)
+           && NET_ReadInt8(packet, (unsigned int *)&query->gamemode)
+           && NET_ReadInt8(packet, (unsigned int *)&query->gamemission);
 
     if (!success)
     {
@@ -196,9 +195,13 @@ void NET_WriteTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff,
     // Write the fields which are enabled:
 
     if (diff->diff & NET_TICDIFF_FORWARD)
+    {
         NET_WriteInt8(packet, diff->cmd.forwardmove);
+    }
     if (diff->diff & NET_TICDIFF_SIDE)
+    {
         NET_WriteInt8(packet, diff->cmd.sidemove);
+    }
     if (diff->diff & NET_TICDIFF_TURN)
     {
         if (lowres_turn)
@@ -211,23 +214,17 @@ void NET_WriteTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff,
         }
     }
     if (diff->diff & NET_TICDIFF_BUTTONS)
+    {
         NET_WriteInt8(packet, diff->cmd.buttons);
+    }
     if (diff->diff & NET_TICDIFF_CONSISTANCY)
+    {
         NET_WriteInt8(packet, diff->cmd.consistancy);
+    }
     if (diff->diff & NET_TICDIFF_CHATCHAR)
+    {
         NET_WriteInt8(packet, diff->cmd.chatchar);
-/*
-    if (diff->diff & NET_TICDIFF_RAVEN)
-    {
-        NET_WriteInt8(packet, diff->cmd.lookfly);
-        NET_WriteInt8(packet, diff->cmd.arti);
     }
-    if (diff->diff & NET_TICDIFF_STRIFE)
-    {
-        NET_WriteInt8(packet, diff->cmd.buttons2);
-        NET_WriteInt16(packet, diff->cmd.inventory);
-    }
-*/
 }
 
 boolean NET_ReadTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff,
@@ -239,21 +236,27 @@ boolean NET_ReadTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff,
     // Read header
 
     if (!NET_ReadInt8(packet, &diff->diff))
+    {
         return false;
-    
+    }
+
     // Read fields
 
     if (diff->diff & NET_TICDIFF_FORWARD)
     {
         if (!NET_ReadSInt8(packet, &sval))
+        {
             return false;
+        }
         diff->cmd.forwardmove = sval;
     }
 
     if (diff->diff & NET_TICDIFF_SIDE)
     {
         if (!NET_ReadSInt8(packet, &sval))
+        {
             return false;
+        }
         diff->cmd.sidemove = sval;
     }
 
@@ -262,13 +265,17 @@ boolean NET_ReadTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff,
         if (lowres_turn)
         {
             if (!NET_ReadSInt8(packet, &sval))
+            {
                 return false;
+            }
             diff->cmd.angleturn = sval * 256;
         }
         else
         {
             if (!NET_ReadSInt16(packet, &sval))
+            {
                 return false;
+            }
             diff->cmd.angleturn = sval;
         }
     }
@@ -276,46 +283,30 @@ boolean NET_ReadTiccmdDiff(net_packet_t *packet, net_ticdiff_t *diff,
     if (diff->diff & NET_TICDIFF_BUTTONS)
     {
         if (!NET_ReadInt8(packet, &val))
+        {
             return false;
+        }
         diff->cmd.buttons = val;
     }
 
     if (diff->diff & NET_TICDIFF_CONSISTANCY)
     {
         if (!NET_ReadInt8(packet, &val))
+        {
             return false;
+        }
         diff->cmd.consistancy = val;
     }
 
     if (diff->diff & NET_TICDIFF_CHATCHAR)
     {
         if (!NET_ReadInt8(packet, &val))
+        {
             return false;
+        }
         diff->cmd.chatchar = val;
     }
-/*
-    if (diff->diff & NET_TICDIFF_RAVEN)
-    {
-        if (!NET_ReadInt8(packet, &val))
-            return false;
-        diff->cmd.lookfly = val;
 
-        if (!NET_ReadInt8(packet, &val))
-            return false;
-        diff->cmd.arti = val;
-    }
-
-    if (diff->diff & NET_TICDIFF_STRIFE)
-    {
-        if (!NET_ReadInt8(packet, &val))
-            return false;
-        diff->cmd.buttons2 = val;
-
-        if (!NET_ReadInt16(packet, &val))
-            return false;
-        diff->cmd.inventory = val;
-    }
-*/
     return true;
 }
 
@@ -325,28 +316,29 @@ void NET_TiccmdDiff(ticcmd_t *tic1, ticcmd_t *tic2, net_ticdiff_t *diff)
     diff->cmd = *tic2;
 
     if (tic1->forwardmove != tic2->forwardmove)
+    {
         diff->diff |= NET_TICDIFF_FORWARD;
+    }
     if (tic1->sidemove != tic2->sidemove)
+    {
         diff->diff |= NET_TICDIFF_SIDE;
+    }
     if (tic1->angleturn != tic2->angleturn)
+    {
         diff->diff |= NET_TICDIFF_TURN;
+    }
     if (tic1->buttons != tic2->buttons)
+    {
         diff->diff |= NET_TICDIFF_BUTTONS;
+    }
     if (tic1->consistancy != tic2->consistancy)
+    {
         diff->diff |= NET_TICDIFF_CONSISTANCY;
+    }
     if (tic2->chatchar != 0)
+    {
         diff->diff |= NET_TICDIFF_CHATCHAR;
-
-    // Heretic/Hexen-specific
-/*
-    if (tic1->lookfly != tic2->lookfly || tic2->arti != 0)
-        diff->diff |= NET_TICDIFF_RAVEN;
-
-    // Strife-specific
-
-    if (tic1->buttons2 != tic2->buttons2 || tic2->inventory != 0)
-        diff->diff |= NET_TICDIFF_STRIFE;
-*/
+    }
 }
 
 void NET_TiccmdPatch(ticcmd_t *src, net_ticdiff_t *diff, ticcmd_t *dest)
@@ -356,52 +348,42 @@ void NET_TiccmdPatch(ticcmd_t *src, net_ticdiff_t *diff, ticcmd_t *dest)
     // Apply the diff
 
     if (diff->diff & NET_TICDIFF_FORWARD)
+    {
         dest->forwardmove = diff->cmd.forwardmove;
+    }
     if (diff->diff & NET_TICDIFF_SIDE)
+    {
         dest->sidemove = diff->cmd.sidemove;
+    }
     if (diff->diff & NET_TICDIFF_TURN)
+    {
         dest->angleturn = diff->cmd.angleturn;
+    }
     if (diff->diff & NET_TICDIFF_BUTTONS)
+    {
         dest->buttons = diff->cmd.buttons;
+    }
     if (diff->diff & NET_TICDIFF_CONSISTANCY)
+    {
         dest->consistancy = diff->cmd.consistancy;
+    }
 
     if (diff->diff & NET_TICDIFF_CHATCHAR)
+    {
         dest->chatchar = diff->cmd.chatchar;
+    }
     else
+    {
         dest->chatchar = 0;
-
-    // Heretic/Hexen specific:
-/*
-    if (diff->diff & NET_TICDIFF_RAVEN)
-    {
-        dest->lookfly = diff->cmd.lookfly;
-        dest->arti = diff->cmd.arti;
     }
-    else
-    {
-        dest->arti = 0;
-    }
-
-    // Strife-specific:
-
-    if (diff->diff & NET_TICDIFF_STRIFE)
-    {
-        dest->buttons2 = diff->cmd.buttons2;
-        dest->inventory = diff->cmd.inventory;
-    }
-    else
-    {
-        dest->inventory = 0;
-    }
-*/
 }
 
-// 
+//
 // net_full_ticcmd_t
-// 
+//
 
-boolean NET_ReadFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd, boolean lowres_turn)
+boolean NET_ReadFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd,
+                           boolean lowres_turn)
 {
     unsigned int bitfield;
     int i;
@@ -419,15 +401,15 @@ boolean NET_ReadFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd, boolean
     {
         return false;
     }
-          
-    for (i=0; i<NET_MAXPLAYERS; ++i)
+
+    for (i = 0; i < NET_MAXPLAYERS; ++i)
     {
         cmd->playeringame[i] = (bitfield & (1 << i)) != 0;
     }
-        
+
     // Read cmds
 
-    for (i=0; i<NET_MAXPLAYERS; ++i)
+    for (i = 0; i < NET_MAXPLAYERS; ++i)
     {
         if (cmd->playeringame[i])
         {
@@ -441,7 +423,8 @@ boolean NET_ReadFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd, boolean
     return true;
 }
 
-void NET_WriteFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd, boolean lowres_turn)
+void NET_WriteFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd,
+                         boolean lowres_turn)
 {
     unsigned int bitfield;
     int i;
@@ -454,20 +437,20 @@ void NET_WriteFullTiccmd(net_packet_t *packet, net_full_ticcmd_t *cmd, boolean l
     // in this ticcmd
 
     bitfield = 0;
-    
-    for (i=0; i<NET_MAXPLAYERS; ++i)
+
+    for (i = 0; i < NET_MAXPLAYERS; ++i)
     {
         if (cmd->playeringame[i])
         {
             bitfield |= 1 << i;
         }
     }
-    
+
     NET_WriteInt8(packet, bitfield);
 
     // Write player ticcmds
 
-    for (i=0; i<NET_MAXPLAYERS; ++i)
+    for (i = 0; i < NET_MAXPLAYERS; ++i)
     {
         if (cmd->playeringame[i])
         {
@@ -503,12 +486,12 @@ boolean NET_ReadWaitData(net_packet_t *packet, net_waitdata_t *data)
     int i;
     char *s;
 
-    if (!NET_ReadInt8(packet, (unsigned int *) &data->num_players)
-     || !NET_ReadInt8(packet, (unsigned int *) &data->num_drones)
-     || !NET_ReadInt8(packet, (unsigned int *) &data->ready_players)
-     || !NET_ReadInt8(packet, (unsigned int *) &data->max_players)
-     || !NET_ReadInt8(packet, (unsigned int *) &data->is_controller)
-     || !NET_ReadSInt8(packet, &data->consoleplayer))
+    if (!NET_ReadInt8(packet, (unsigned int *)&data->num_players)
+        || !NET_ReadInt8(packet, (unsigned int *)&data->num_drones)
+        || !NET_ReadInt8(packet, (unsigned int *)&data->ready_players)
+        || !NET_ReadInt8(packet, (unsigned int *)&data->max_players)
+        || !NET_ReadInt8(packet, (unsigned int *)&data->is_controller)
+        || !NET_ReadSInt8(packet, &data->consoleplayer))
     {
         return false;
     }
@@ -535,8 +518,8 @@ boolean NET_ReadWaitData(net_packet_t *packet, net_waitdata_t *data)
     }
 
     return NET_ReadSHA1Sum(packet, data->wad_sha1sum)
-        && NET_ReadSHA1Sum(packet, data->deh_sha1sum)
-        && NET_ReadInt8(packet, (unsigned int *) &data->is_freedoom);
+           && NET_ReadSHA1Sum(packet, data->deh_sha1sum)
+           && NET_ReadInt8(packet, (unsigned int *)&data->is_freedoom);
 }
 
 static boolean NET_ReadBlob(net_packet_t *packet, uint8_t *buf, size_t len)
@@ -544,7 +527,7 @@ static boolean NET_ReadBlob(net_packet_t *packet, uint8_t *buf, size_t len)
     unsigned int b;
     int i;
 
-    for (i=0; i<len; ++i)
+    for (i = 0; i < len; ++i)
     {
         if (!NET_ReadInt8(packet, &b))
         {
@@ -561,7 +544,7 @@ static void NET_WriteBlob(net_packet_t *packet, uint8_t *buf, size_t len)
 {
     int i;
 
-    for (i=0; i<len; ++i)
+    for (i = 0; i < len; ++i)
     {
         NET_WriteInt8(packet, buf[i]);
     }
@@ -576,17 +559,7 @@ void NET_WriteSHA1Sum(net_packet_t *packet, sha1_digest_t digest)
 {
     NET_WriteBlob(packet, digest, sizeof(sha1_digest_t));
 }
-/*
-boolean NET_ReadPRNGSeed(net_packet_t *packet, prng_seed_t seed)
-{
-    return NET_ReadBlob(packet, seed, sizeof(prng_seed_t));
-}
 
-void NET_WritePRNGSeed(net_packet_t *packet, prng_seed_t seed)
-{
-    NET_WriteBlob(packet, seed, sizeof(prng_seed_t));
-}
-*/
 static net_protocol_t ParseProtocolName(const char *name)
 {
     int i;
@@ -635,7 +608,8 @@ void NET_WriteProtocol(net_packet_t *packet, net_protocol_t protocol)
     // If you add an entry to the net_protocol_t enum, a corresponding entry
     // must be added to the protocol_names list.
     I_Error("NET_WriteProtocol: protocol %d missing from protocol_names "
-            "list; please add it.", protocol);
+            "list; please add it.",
+            protocol);
 }
 
 // NET_ReadProtocolList reads a list of string-format protocol names from
@@ -692,4 +666,3 @@ void NET_WriteProtocolList(net_packet_t *packet)
         NET_WriteProtocol(packet, i);
     }
 }
-
