@@ -420,10 +420,9 @@ boolean P_BlockLinesIterator(int x, int y, boolean func(line_t*))
 // killough 5/3/98: reformatted, cleaned up
 
 boolean blockmapfix;
-extern boolean PIT_RadiusAttack(mobj_t* thing);
-extern boolean PIT_ChangeSector(mobj_t* thing);
 
-boolean P_BlockThingsIterator(int x, int y, boolean func(mobj_t*))
+boolean P_BlockThingsIterator(int x, int y, boolean func(mobj_t*),
+                              boolean do_blockmapfix)
 {
   mobj_t *mobj;
 
@@ -437,15 +436,11 @@ boolean P_BlockThingsIterator(int x, int y, boolean func(mobj_t*))
   // Blockmap bug fix by Terry Hearst
   // https://github.com/fabiangreffrath/crispy-doom/pull/723
   // Add other mobjs from surrounding blocks that overlap this one
-  if (CRITICAL(blockmapfix))
+  if (CRITICAL(blockmapfix) && do_blockmapfix)
   {
     if (demo_compatibility && overflow[emu_intercepts].enabled)
       return true;
 
-    // Don't do for explosions and crashers
-    if (func == PIT_RadiusAttack || func == PIT_ChangeSector)
-      return true;
-
     // Unwrapped for least number of bounding box checks
     // (-1, -1)
     if (x > 0 && y > 0)
@@ -704,8 +699,6 @@ boolean P_TraverseIntercepts(traverser_t func, fixed_t maxfrac)
   return true;                  // everything was traversed
 }
 
-extern fixed_t bulletslope;
-
 // Intercepts Overrun emulation, from PrBoom-plus.
 // Thanks to Andrey Budko (entryway) for researching this and his 
 // implementation of Intercepts Overrun emulation in PrBoom-plus
@@ -714,8 +707,8 @@ extern fixed_t bulletslope;
 typedef struct
 {
     int len;
-    void *addr;
     boolean int16_array;
+    void *addr;
 } intercepts_overrun_t;
 
 // Intercepts memory table.  This is where various variables are located
@@ -728,29 +721,29 @@ typedef struct
 
 static intercepts_overrun_t intercepts_overrun[] =
 {
-    {4,   NULL,                          false},
-    {4,   NULL, /* &earlyout, */         false},
-    {4,   NULL, /* &intercept_p, */      false},
-    {4,   &lowfloor,                     false},
-    {4,   &openbottom,                   false},
-    {4,   &opentop,                      false},
-    {4,   &openrange,                    false},
-    {4,   NULL,                          false},
-    {120, NULL, /* &activeplats, */      false},
-    {8,   NULL,                          false},
-    {4,   &bulletslope,                  false},
-    {4,   NULL, /* &swingx, */           false},
-    {4,   NULL, /* &swingy, */           false},
-    {4,   NULL,                          false},
-    {40,  &playerstarts,                 true},
-    {4,   NULL, /* &blocklinks, */       false},
-    {4,   &bmapwidth,                    false},
-    {4,   NULL, /* &blockmap, */         false},
-    {4,   &bmaporgx,                     false},
-    {4,   &bmaporgy,                     false},
-    {4,   NULL, /* &blockmaplump, */     false},
-    {4,   &bmapheight,                   false},
-    {0,   NULL,                          false},
+    {4,   false, NULL,                     },
+    {4,   false, NULL, /* &earlyout, */    },
+    {4,   false, NULL, /* &intercept_p, */ },
+    {4,   false, &lowfloor,                },
+    {4,   false, &openbottom,              },
+    {4,   false, &opentop,                 },
+    {4,   false, &openrange,               },
+    {4,   false, NULL,                     },
+    {120, false, NULL, /* &activeplats, */ },
+    {8,   false, NULL,                     },
+    {4,   false, &bulletslope,             },
+    {4,   false, NULL, /* &swingx, */      },
+    {4,   false, NULL, /* &swingy, */      },
+    {4,   false, NULL,                     },
+    {40,  true,  &playerstarts,            },
+    {4,   false, NULL, /* &blocklinks, */  },
+    {4,   false, &bmapwidth,               },
+    {4,   false, NULL, /* &blockmap, */    },
+    {4,   false, &bmaporgx,                },
+    {4,   false, &bmaporgy,                },
+    {4,   false, NULL, /* &blockmaplump, */},
+    {4,   false, &bmapheight,              },
+    {0,   false, NULL,                     },
 };
 
 // Overwrite a specific memory location with a value.
@@ -780,8 +773,8 @@ static void InterceptsMemoryOverrun(int location, int value)
                 if (intercepts_overrun[i].int16_array)
                 {
                     index = (location - offset) / 2;
-                    ((short *) addr)[index] = value & 0xffff;
-                    ((short *) addr)[index + 1] = (value >> 16) & 0xffff;
+                    ((short *) addr)[index] = value & FRACMASK;
+                    ((short *) addr)[index + 1] = (value >> 16) & FRACMASK;
                 }
                 else
                 {
@@ -877,14 +870,14 @@ boolean P_PathTraverse(fixed_t x1, fixed_t y1, fixed_t x2, fixed_t y2,
   if (xt2 > xt1)
     {
       mapxstep = 1;
-      partial = FRACUNIT - ((x1>>MAPBTOFRAC)&(FRACUNIT-1));
+      partial = FRACUNIT - ((x1>>MAPBTOFRAC)&FRACMASK);
       ystep = FixedDiv (y2-y1,abs(x2-x1));
     }
   else
     if (xt2 < xt1)
       {
         mapxstep = -1;
-        partial = (x1>>MAPBTOFRAC)&(FRACUNIT-1);
+        partial = (x1>>MAPBTOFRAC)&FRACMASK;
         ystep = FixedDiv (y2-y1,abs(x2-x1));
       }
     else
@@ -899,14 +892,14 @@ boolean P_PathTraverse(fixed_t x1, fixed_t y1, fixed_t x2, fixed_t y2,
   if (yt2 > yt1)
     {
       mapystep = 1;
-      partial = FRACUNIT - ((y1>>MAPBTOFRAC)&(FRACUNIT-1));
+      partial = FRACUNIT - ((y1>>MAPBTOFRAC)&FRACMASK);
       xstep = FixedDiv (x2-x1,abs(y2-y1));
     }
   else
     if (yt2 < yt1)
       {
         mapystep = -1;
-        partial = (y1>>MAPBTOFRAC)&(FRACUNIT-1);
+        partial = (y1>>MAPBTOFRAC)&FRACMASK;
         xstep = FixedDiv (x2-x1,abs(y2-y1));
       }
     else
@@ -928,11 +921,11 @@ boolean P_PathTraverse(fixed_t x1, fixed_t y1, fixed_t x2, fixed_t y2,
   for (count = 0; count < 64; count++)
     {
       if (flags & PT_ADDLINES)
-        if (!P_BlockLinesIterator(mapx, mapy,PIT_AddLineIntercepts))
+        if (!P_BlockLinesIterator(mapx, mapy, PIT_AddLineIntercepts))
           return false; // early out
 
       if (flags & PT_ADDTHINGS)
-        if (!P_BlockThingsIterator(mapx, mapy,PIT_AddThingIntercepts))
+        if (!P_BlockThingsIterator(mapx, mapy, PIT_AddThingIntercepts, true))
           return false; // early out
 
       if (mapx == xt2 && mapy == yt2)
@@ -1208,7 +1201,7 @@ static boolean P_SightTraverseIntercepts(void)
   //
   // go through in order
   //
-  in = 0; // shut up compiler warning
+  in = NULL; // shut up compiler warning
 
   while (count--)
   {
@@ -1220,9 +1213,12 @@ static boolean P_SightTraverseIntercepts(void)
         in = scan;
       }
 
-    if (!PTR_SightTraverse(in))
+    if (in)
+    {
+      if (!PTR_SightTraverse(in))
         return false;      // don't bother going farther
       in->frac = INT_MAX;
+    }
   }
 
   return true;    // everything was traversed
@@ -1278,13 +1274,13 @@ boolean P_SightPathTraverse(fixed_t x1, fixed_t y1, fixed_t x2, fixed_t y2)
   if (xt2 > xt1)
   {
     mapxstep = 1;
-    partial = FRACUNIT - ((x1>>MAPBTOFRAC)&(FRACUNIT-1));
+    partial = FRACUNIT - ((x1>>MAPBTOFRAC)&FRACMASK);
     ystep = FixedDiv (y2-y1,abs(x2-x1));
   }
   else if (xt2 < xt1)
   {
     mapxstep = -1;
-    partial = (x1>>MAPBTOFRAC)&(FRACUNIT-1);
+    partial = (x1>>MAPBTOFRAC)&FRACMASK;
     ystep = FixedDiv (y2-y1,abs(x2-x1));
   }
   else
@@ -1299,13 +1295,13 @@ boolean P_SightPathTraverse(fixed_t x1, fixed_t y1, fixed_t x2, fixed_t y2)
   if (yt2 > yt1)
   {
     mapystep = 1;
-    partial = FRACUNIT - ((y1>>MAPBTOFRAC)&(FRACUNIT-1));
+    partial = FRACUNIT - ((y1>>MAPBTOFRAC)&FRACMASK);
     xstep = FixedDiv (x2-x1,abs(y2-y1));
   }
   else if (yt2 < yt1)
   {
     mapystep = -1;
-    partial = (y1>>MAPBTOFRAC)&(FRACUNIT-1);
+    partial = (y1>>MAPBTOFRAC)&FRACMASK;
     xstep = FixedDiv (x2-x1,abs(y2-y1));
   }
   else
