@@ -66,7 +66,8 @@ void    P_LineOpening(struct line_s *linedef);
 void    P_UnsetThingPosition(struct mobj_s *thing);
 void    P_SetThingPosition(struct mobj_s *thing);
 boolean P_BlockLinesIterator (int x, int y, boolean func(struct line_s *));
-boolean P_BlockThingsIterator(int x, int y, boolean func(struct mobj_s *));
+boolean P_BlockThingsIterator(int x, int y, boolean func(struct mobj_s *),
+                              boolean do_blockmapfix);
 boolean ThingIsOnLine(struct mobj_s *t, struct line_s *l);  // killough 3/15/98
 boolean P_PathTraverse(fixed_t x1, fixed_t y1, fixed_t x2, fixed_t y2,
                        int flags, boolean trav(intercept_t *));
@@ -84,6 +85,8 @@ extern fixed_t openrange;
 extern fixed_t lowfloor;
 extern divline_t trace;
 
+extern boolean blockmapfix;
+
 #endif  // __P_MAPUTL__
 
 //----------------------------------------------------------------------------
