@@ -48,11 +48,31 @@
 #include "z_zone.h"
 
 boolean direct_vertical_aiming, default_direct_vertical_aiming;
+int max_pitch_angle = 32 * ANG1, default_max_pitch_angle;
 
 void P_UpdateDirectVerticalAiming(void)
 {
   direct_vertical_aiming = (CRITICAL(default_direct_vertical_aiming) &&
                             (mouselook || padlook));
+  max_pitch_angle = default_max_pitch_angle * ANG1;
+}
+
+void P_SetActualHeight(mobj_t *mobj)
+{
+    const spritedef_t *sprdef = &sprites[mobj->sprite];
+    const spriteframe_t *sprframe = NULL;
+    if (sprdef && sprdef->spriteframes)
+    {
+        sprframe = &sprdef->spriteframes[mobj->frame & FF_FRAMEMASK];
+    }
+    if (sprframe)
+    {
+        mobj->actualheight = spritetopoffset[sprframe->lump[0]];
+    }
+    else
+    {
+        mobj->actualheight = FixedToInt(mobj->height);
+    }
 }
 
 //
@@ -117,7 +137,7 @@ boolean P_SetMobjState(mobj_t* mobj,statenum_t state)
   // [FG] update object's actual height
   if (ret)
   {
-    mobj->actualheight = spritetopoffset[sprites[mobj->sprite].spriteframes[mobj->frame & FF_FRAMEMASK].lump[0]];
+    P_SetActualHeight(mobj);
   }
 
   return ret;
@@ -868,15 +888,6 @@ mobj_t *P_SpawnMobj(fixed_t x, fixed_t y, fixed_t z, mobjtype_t type)
   // NULL head of sector list // phares 3/13/98
   mobj->touching_sectorlist = NULL;
 
-  // [AM] Do not interpolate on spawn.
-  mobj->interp = false;
-
-  // [AM] Just in case interpolation is attempted...
-  mobj->oldx = mobj->x;
-  mobj->oldy = mobj->y;
-  mobj->oldz = mobj->z;
-  mobj->oldangle = mobj->angle;
-
   // set subsector and/or block links
 
   P_SetThingPosition(mobj);
@@ -888,6 +899,15 @@ mobj_t *P_SpawnMobj(fixed_t x, fixed_t y, fixed_t z, mobjtype_t type)
   mobj->z = z == ONFLOORZ ? mobj->floorz : z == ONCEILINGZ ?
     mobj->ceilingz - mobj->height : z;
 
+  // [AM] Do not interpolate on spawn.
+  mobj->interp = false;
+
+  // [AM] Just in case interpolation is attempted...
+  mobj->oldx = mobj->x;
+  mobj->oldy = mobj->y;
+  mobj->oldz = mobj->z;
+  mobj->oldangle = mobj->angle;
+
   mobj->thinker.function.p1 = (actionf_p1)P_MobjThinker;
   mobj->above_thing = mobj->below_thing = 0;           // phares
 
@@ -904,7 +924,7 @@ mobj_t *P_SpawnMobj(fixed_t x, fixed_t y, fixed_t z, mobjtype_t type)
   }
 
   // [FG] initialize object's actual height
-  mobj->actualheight = spritetopoffset[sprites[st->sprite].spriteframes[st->frame & FF_FRAMEMASK].lump[0]];
+  P_SetActualHeight(mobj);
 
   P_AddThinker(&mobj->thinker);
 
@@ -1316,7 +1336,7 @@ spawnit:
   if (mobj->flags & MF_COUNTITEM)
     totalitems++;
 
-  mobj->angle = ANG45 * (mthing->angle/45);
+  mobj->angle = (angle_t)ANG45 * (mthing->angle/45);
   if (mthing->options & MTF_AMBUSH)
     mobj->flags |= MF_AMBUSH;
 
