@@ -420,11 +420,14 @@ extern int iquehead;
 extern int iquetail;
 
 extern boolean direct_vertical_aiming, default_direct_vertical_aiming;
+extern int max_pitch_angle, default_max_pitch_angle;
 void P_UpdateDirectVerticalAiming(void);
 
 extern boolean checksight12;
 void P_UpdateCheckSight(void);
 
+void P_SetActualHeight(mobj_t *mobj);
+
 mobj_t *P_SubstNullMobj(mobj_t *mobj);
 void    P_RespawnSpecials(void);
 mobj_t  *P_SpawnMobj(fixed_t x, fixed_t y, fixed_t z, mobjtype_t type);
