@@ -250,7 +250,7 @@ void P_MovePlayer (player_t* player)
   if (!menuactive && !demoplayback && !player->centering)
   {
     player->pitch += cmd->pitch << FRACBITS;
-    player->pitch = BETWEEN(-MAX_PITCH_ANGLE, MAX_PITCH_ANGLE, player->pitch);
+    player->pitch = BETWEEN(-max_pitch_angle, max_pitch_angle, player->pitch);
     player->slope = PlayerSlope(player);
   }
 }
@@ -383,19 +383,11 @@ void P_PlayerThink (player_t* player)
     }
 
   // [crispy] center view
-  #define CENTERING_VIEW_ANGLE (4 * ANG1)
-
   if (player->centering)
   {
-    if (player->pitch > 0)
-    {
-      player->pitch -= CENTERING_VIEW_ANGLE;
-    }
-    else if (player->pitch < 0)
-    {
-      player->pitch += CENTERING_VIEW_ANGLE;
-    }
-    if (abs(player->pitch) < CENTERING_VIEW_ANGLE)
+    player->pitch /= 2;
+
+    if (abs(player->pitch) < ANG1)
     {
       player->pitch = 0;
 
@@ -517,7 +509,7 @@ void P_PlayerThink (player_t* player)
 	  {
 	    // to match the timer, we use the leveltime value at the end of the frame
 	    player->btuse = leveltime + 1;
-	    player->btuse_tics = 5*TICRATE/2; // [crispy] 2.5 seconds
+	    player->btuse_tics = 5*TICRATE/2 + 1; // [crispy] 2.5 seconds
 	  }
 	}
     }
@@ -530,6 +522,9 @@ void P_PlayerThink (player_t* player)
 
   // Counters, time dependent power ups.
 
+  if (player->btuse_tics > 0)
+    player->btuse_tics--;
+
   // Strength counts up to diminish fade.
 
   if (player->powers[pw_strength])
