@@ -25,8 +25,7 @@
 
 // Retrieve column data for span blitting.
 byte *R_GetColumn(int tex, int col);
-byte *R_GetColumnMod(int tex, int col);
-byte *R_GetColumnMod2(int tex, int col);
+byte *R_GetColumnMasked(int tex, int col);
 
 // I/O, setting up the stuff.
 void R_InitData (void);
