@@ -33,6 +33,7 @@
 #ifndef __TABLES__
 #define __TABLES__
 
+#include "doomtype.h" // inline
 #include "m_fixed.h"
 
 #define FINEANGLES              8192
@@ -52,6 +53,7 @@ extern const fixed_t finetangent[FINEANGLES/2];
 
 // Binary Angle Measument, BAM.
 #define ANG45   0x20000000
+#define ANG75   0x35555555
 #define ANG90   0x40000000
 #define ANG180  0x80000000
 #define ANG270  0xc0000000
