@@ -719,7 +719,8 @@ void WI_slamBackground(void)
         name = lump;
     }
 
-    V_DrawPatchFullScreen(V_CachePatchName(name, PU_CACHE));
+    V_DrawPatchFullScreen(
+      V_CachePatchName(W_CheckWidescreenPatch(name), PU_CACHE));
 }
 
 // ====================================================================
@@ -1158,48 +1159,43 @@ WI_drawPercent
 //          t      -- the time value to be drawn
 // Returns: void
 //
-static void
-WI_drawTime
-( int   x,
-  int   y,
-  int   t,
-  boolean suck )
+static void WI_drawTime(int x, int y, int seconds, boolean suck)
 {
-  
-  int   div;
-  int   n;
-
-  if (t<0)
-    return;
-
-  // [FG] total time for all levels never "sucks"
-  if (t <= 61*59 || !suck)  // otherwise known as 60*60 -1 == 3599
+    if (seconds < 0)
     {
-      div = 1;
-
-      do
-        {
-          n = (t / div) % 60;
-          x = WI_drawNum(x, y, n, 2) - SHORT(colon->width);
-          div *= 60;
-
-          // draw
-          if (div==60 || t / div)
-            V_DrawPatch(x, y, colon);
-      
-        } 
-      while (t / div && div < 3600);
-
-      // [FG] print at most in hhhh:mm:ss format
-      if ((n = (t / div)))
-      {
-        WI_drawNum(x, y, n, -1);
-      }
+        return;
     }
-  else
+
+    const int hours = seconds / 3600;
+
+    // [FG] total time for all levels never "sucks"
+    // Updated to match PrBoom's 100 hours, instead of vanilla's 1 hour
+    if (suck && hours >= 100)
     {
-      // "sucks"
-      V_DrawPatch(x - SHORT(sucks->width), y, sucks); 
+        // "sucks"
+        V_DrawPatch(x - SHORT(sucks->width), y, sucks);
+        return;
+    }
+
+    seconds -= hours * 3600;
+    const int minutes = seconds / 60;
+    seconds -= minutes * 60;
+
+    const short colon_width = SHORT(colon->width);
+
+    x = WI_drawNum(x, y, seconds, 2) - colon_width;
+    V_DrawPatch(x, y, colon);
+
+    // [FG] print at most in hhhh:mm:ss format
+    if (hours)
+    {
+        x = WI_drawNum(x, y, minutes, 2) - colon_width;
+        V_DrawPatch(x, y, colon);
+        WI_drawNum(x, y, hours, -1);
+    }
+    else if (minutes)
+    {
+        WI_drawNum(x, y, minutes, -1);
     }
 }
 
@@ -2194,7 +2190,10 @@ static void WI_drawStats(void)
   const boolean wide_time = (wide_total && !draw_partime);
 
   V_DrawPatch(SP_TIMEX, SP_TIMEY, witime);
-  WI_drawTime((wide_time ? SCREENWIDTH : SCREENWIDTH/2) - SP_TIMEX,
+  // Why add a hardcoded +8 you ask?
+  // in oder to allow >1h long times, some minor alignment shifting is needed
+  // i.e. PrBoom switched SP_TIMEX to 8, instead of vanilla's 16
+  WI_drawTime((wide_time ? (SCREENWIDTH - SP_TIMEX) : (SCREENWIDTH/2 + 8)),
               SP_TIMEY, cnt_time, true);
 
   // Ty 04/11/98: redid logic: should skip only if with pwad but 
@@ -2210,7 +2209,7 @@ static void WI_drawStats(void)
 
   // [FG] draw total time alongside level time and par time
   V_DrawPatch(SP_TIMEX, SP_TIMEY + 16, total);
-  WI_drawTime((wide_total ? SCREENWIDTH : SCREENWIDTH/2) - SP_TIMEX,
+  WI_drawTime((wide_total ? (SCREENWIDTH - SP_TIMEX) : (SCREENWIDTH/2 + 8)),
               SP_TIMEY + 16, cnt_total_time, false);
 }
 
