@@ -44,6 +44,12 @@ typedef struct
 // Fonts:
 
 #include "fonts/normal.h"
+
+static const txt_font_t normal_font =
+{
+    "normal", normal_font_data, 8, 16,
+};
+
 #include "fonts/codepage.h"
 
 // Time between character blinks in ms
@@ -175,8 +181,11 @@ int TXT_Init(void)
                                         TXT_SCREEN_H * font->h,
                                         8, 0, 0, 0, 0);
 
+    // Apply aspect ratio correction.
+    const int logical_h = screenbuffer->h * 6 / 5;
+
     // Set width and height of the logical viewport for automatic scaling.
-    SDL_RenderSetLogicalSize(renderer, screenbuffer->w, screenbuffer->h);
+    SDL_RenderSetLogicalSize(renderer, screenbuffer->w, logical_h);
 
     SDL_LockSurface(screenbuffer);
     SDL_SetPaletteColors(screenbuffer->format->palette, ega_colors, 0, 16);
@@ -198,7 +207,7 @@ int TXT_Init(void)
       texture_upscaled = SDL_CreateTexture(renderer,
                            SDL_GetWindowPixelFormat(TXT_SDLWindow),
                            SDL_TEXTUREACCESS_TARGET,
-                           2*screenbuffer->w, 2*screenbuffer->h);
+                           2*screenbuffer->w, 2*logical_h);
     }
 
     return 1;
@@ -586,6 +595,11 @@ signed int TXT_GetChar(void)
                     return 0;
                 }
 
+            case SDL_CONTROLLERDEVICEADDED:
+            case SDL_CONTROLLERDEVICEREMOVED:
+                SDL_PushEvent(&ev);
+                break;
+
             default:
                 break;
         }
